LeaseState

Enum LeaseState 

pub enum LeaseState<K, Route> {
    Vacant {
        next: TimerGeneration,
    },
    Held {
        holder: K,
        generation: TimerGeneration,
        notify: Route,
        next: Option<TimerGeneration>,
    },
    Exhausted,
}
Complete exclusive lease phase.

Variants



Vacant

No holder owns the lease.

Fields

next: TimerGeneration

Generation committed by the next successful acquisition.



Held

One holder owns exactly this timer generation.

Fields

holder: K

Application-defined holder identity.

generation: TimerGeneration

Current expiry generation.

notify: Route

Recipient notified of expiry.

next: Option<TimerGeneration>

Generation available to a renewal or later acquisition. None means this held generation is the final representable one.



Exhausted

No fresh expiry generation is representable and no holder exists.